import time
import threading

import grpc


class CancellableStreamThread:
    def __init__(
        self, callback, create_stream, logger, attribute=None, ignore_unavailable=False
    ):
        """
        Feeds data from the gRPC stream into the callback
        until the cancel method is called.
        """
        self.stream = None
        self._canceled = False

        def target():
            while True:
                try:
                    self.stream = create_stream()
                    if self._canceled:
                        return
                    for _ in self.stream:
                        if attribute is not None:
                            callback(getattr(_, attribute))
                        else:
                            callback(_)
                except grpc.RpcError as e:
                    if e.code() == grpc.StatusCode.CANCELLED:
                        return
                    if logger and not (
                        ignore_unavailable and e.code() == grpc.StatusCode.UNAVAILABLE
                    ):
                        logger.warn("Error creating stream %s" % str(e))
                    if e.code() == grpc.StatusCode.UNAUTHENTICATED:
                        return
                    # wait a short duration before re-registering when
                    # agent unavailable or other rpc error
                    time.sleep(0.1)

        t = threading.Thread(target=target,name="CancellableStreamThread")
        t.daemon = True
        t.start()

    def cancel(self):
        self._canceled = True
        if self.stream is not None:
            self.stream.cancel()



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: protos/agent/v1/agent.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from formant.protos.model.v1 import datapoint_pb2 as protos_dot_model_dot_v1_dot_datapoint__pb2
from formant.protos.model.v1 import intervention_pb2 as protos_dot_model_dot_v1_dot_intervention__pb2
from formant.protos.model.v1 import commands_pb2 as protos_dot_model_dot_v1_dot_commands__pb2
from formant.protos.model.v1 import config_pb2 as protos_dot_model_dot_v1_dot_config__pb2
from formant.protos.model.v1 import math_pb2 as protos_dot_model_dot_v1_dot_math__pb2
from formant.protos.model.v1 import event_pb2 as protos_dot_model_dot_v1_dot_event__pb2
from formant.protos.model.v1 import health_pb2 as protos_dot_model_dot_v1_dot_health__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='protos/agent/v1/agent.proto',
  package='v1.agent',
  syntax='proto3',
  serialized_options=b'Z)github.com/FormantIO/genproto/go/v1/agent',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1bprotos/agent/v1/agent.proto\x12\x08v1.agent\x1a\x1fprotos/model/v1/datapoint.proto\x1a\"protos/model/v1/intervention.proto\x1a\x1eprotos/model/v1/commands.proto\x1a\x1cprotos/model/v1/config.proto\x1a\x1aprotos/model/v1/math.proto\x1a\x1bprotos/model/v1/event.proto\x1a\x1cprotos/model/v1/health.proto\"S\n\'PostGenericAPIUnbufferedRequestResponse\x12\x12\n\nstatusCode\x18\x01 \x01(\r\x12\x14\n\x0cresponseBody\x18\x02 \x01(\t\"\x1f\n\x1dPostGenericAPIRequestResponse\"\x14\n\x12StreamDataResponse\"\x12\n\x10PostDataResponse\"P\n\rPostDataError\x12\r\n\x05index\x18\x01 \x01(\r\x12\x0c\n\x04\x63ode\x18\x02 \x01(\r\x12\x11\n\tretryable\x18\x03 \x01(\x08\x12\x0f\n\x07message\x18\x04 \x01(\t\"?\n\x14PostDataMultiRequest\x12\'\n\ndatapoints\x18\x01 \x03(\x0b\x32\x13.v1.model.Datapoint\"\x17\n\x15PostDataMultiResponse\"=\n\x12PostDataMultiError\x12\'\n\x06\x65rrors\x18\x01 \x03(\x0b\x32\x17.v1.agent.PostDataError\"+\n\x1dGetInterventionRequestRequest\x12\n\n\x02id\x18\x01 \x01(\t\"4\n\x1eGetInterventionResponseRequest\x12\x12\n\nrequest_id\x18\x01 \x01(\t\" \n\x1eGetStreamsConfigurationRequest\"Q\n\x1fGetStreamsConfigurationResponse\x12.\n\x07streams\x18\x01 \x03(\x0b\x32\x1d.v1.model.StreamConfiguration\"$\n\"GetApplicationConfigurationRequest\"`\n#GetApplicationConfigurationResponse\x12\x39\n\rconfiguration\x18\x01 \x01(\x0b\x32\".v1.model.ApplicationConfiguration\"\x1a\n\x18GetConfigBlobDataRequest\"B\n\x19GetConfigBlobDataResponse\x12%\n\tblob_data\x18\x01 \x01(\x0b\x32\x12.v1.model.BlobData\"\x1e\n\x1cGetAgentConfigurationRequest\"T\n\x1dGetAgentConfigurationResponse\x12\x33\n\rconfiguration\x18\x01 \x01(\x0b\x32\x1c.v1.model.AgentConfiguration\"\x1a\n\x18GetBufferMetadataRequest\"h\n\x16QueryDatapointsRequest\x12\x13\n\x0bstream_name\x18\x01 \x01(\t\x12\r\n\x05start\x18\x02 \x01(\t\x12\x0b\n\x03\x65nd\x18\x03 \x01(\t\x12\r\n\x05limit\x18\x04 \x01(\r\x12\x0e\n\x06offset\x18\x05 \x01(\r\"?\n\x17QueryDatapointsResponse\x12$\n\x07results\x18\x01 \x03(\x0b\x32\x13.v1.model.Datapoint\"O\n\x12QueryEventsRequest\x12\r\n\x05start\x18\x01 \x01(\t\x12\x0b\n\x03\x65nd\x18\x02 \x01(\t\x12\r\n\x05limit\x18\x03 \x01(\r\x12\x0e\n\x06offset\x18\x04 \x01(\r\"7\n\x13QueryEventsResponse\x12 \n\x07results\x18\x01 \x03(\x0b\x32\x0f.v1.model.Event\"J\n\x19GetBufferMetadataResponse\x12-\n\x0b\x63onnections\x18\x01 \x03(\x0b\x32\x18.v1.model.BufferMetadata\"\x0f\n\rHealthRequest\"\x10\n\x0eHealthResponse\"2\n\x18GetCommandRequestRequest\x12\x16\n\x0e\x63ommand_filter\x18\x01 \x03(\t\"F\n\x19GetCommandRequestResponse\x12)\n\x07request\x18\x01 \x01(\x0b\x32\x18.v1.model.CommandRequest\"I\n\x1aSendCommandResponseRequest\x12+\n\x08response\x18\x01 \x01(\x0b\x32\x19.v1.model.CommandResponse\"\x1d\n\x1bSendCommandResponseResponse\"8\n\x1eGetCommandRequestStreamRequest\x12\x16\n\x0e\x63ommand_filter\x18\x01 \x03(\t\"L\n\x1fGetCommandRequestStreamResponse\x12)\n\x07request\x18\x01 \x01(\x0b\x32\x18.v1.model.CommandRequest\":\n!GetTeleopControlDataStreamRequest\x12\x15\n\rstream_filter\x18\x01 \x03(\t\"[\n\"GetTeleopControlDataStreamResponse\x12\x35\n\x11\x63ontrol_datapoint\x18\x01 \x01(\x0b\x32\x1a.v1.model.ControlDatapoint\"!\n\x1fGetTeleopHeartbeatStreamRequest\"`\n GetTeleopHeartbeatStreamResponse\x12\x0f\n\x07peer_id\x18\x01 \x01(\t\x12\x15\n\ris_disconnect\x18\x02 \x01(\x08\x12\x14\n\x0csession_type\x18\x03 \x01(\t\":\n!GetTelemetryListenerStreamRequest\x12\x15\n\rstream_filter\x18\x01 \x03(\t\"L\n\"GetTelemetryListenerStreamResponse\x12&\n\tdatapoint\x18\x01 \x01(\x0b\x32\x13.v1.model.Datapoint\"\x1c\n\x1aPostTransformFrameResponse\"#\n\x15SetBaseFrameIDRequest\x12\n\n\x02id\x18\x01 \x01(\t\"\x18\n\x16SetBaseFrameIDResponse\"\x1b\n\x19\x43learTransformTreeRequest\"\x1c\n\x1a\x43learTransformTreeResponse\"4\n\x12\x43reateEventRequest\x12\x1e\n\x05\x65vent\x18\x01 \x01(\x0b\x32\x0f.v1.model.Event\"\x15\n\x13\x43reateEventResponse\"%\n\x10\x43reateEventError\x12\x11\n\tretryable\x18\x01 \x01(\x08\"\x16\n\x14GetTeleopInfoRequest\"1\n\x15GetTeleopInfoResponse\x12\x18\n\x10\x63onnection_count\x18\x01 \x01(\r\"\'\n\x16PostLanRtcOfferRequest\x12\r\n\x05offer\x18\x01 \x01(\t\")\n\x17PostLanRtcOfferResponse\x12\x0e\n\x06\x61nswer\x18\x01 \x01(\t\"G\n\x1eSendOnCustomDataChannelRequest\x12\x14\n\x0c\x63hannel_name\x18\x01 \x01(\t\x12\x0f\n\x07payload\x18\x02 \x01(\x0c\"!\n\x1fSendOnCustomDataChannelResponse\"G\n(GetCustomDataChannelMessageStreamRequest\x12\x1b\n\x13\x63hannel_name_filter\x18\x01 \x03(\t\"c\n)GetCustomDataChannelMessageStreamResponse\x12\x0f\n\x07peer_id\x18\x01 \x01(\t\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x0f\n\x07payload\x18\x03 \x01(\x0c\x32\xa2\x17\n\x05\x41gent\x12\x43\n\nStreamData\x12\x13.v1.model.Datapoint\x1a\x1c.v1.agent.StreamDataResponse\"\x00(\x01\x12=\n\x08PostData\x12\x13.v1.model.Datapoint\x1a\x1a.v1.agent.PostDataResponse\"\x00\x12R\n\rPostDataMulti\x12\x1e.v1.agent.PostDataMultiRequest\x1a\x1f.v1.agent.PostDataMultiResponse\"\x00\x12{\n\x1aGetTeleopControlDataStream\x12+.v1.agent.GetTeleopControlDataStreamRequest\x1a,.v1.agent.GetTeleopControlDataStreamResponse\"\x00\x30\x01\x12u\n\x18GetTeleopHeartbeatStream\x12).v1.agent.GetTeleopHeartbeatStreamRequest\x1a*.v1.agent.GetTeleopHeartbeatStreamResponse\"\x00\x30\x01\x12{\n\x1aGetTelemetryListenerStream\x12+.v1.agent.GetTelemetryListenerStreamRequest\x1a,.v1.agent.GetTelemetryListenerStreamResponse\"\x00\x30\x01\x12\x90\x01\n!GetCustomDataChannelMessageStream\x12\x32.v1.agent.GetCustomDataChannelMessageStreamRequest\x1a\x33.v1.agent.GetCustomDataChannelMessageStreamResponse\"\x00\x30\x01\x12L\n\x0b\x43reateEvent\x12\x1c.v1.agent.CreateEventRequest\x1a\x1d.v1.agent.CreateEventResponse\"\x00\x12[\n\x19\x43reateInterventionRequest\x12\x1d.v1.model.InterventionRequest\x1a\x1d.v1.model.InterventionRequest\"\x00\x12\x62\n\x16GetInterventionRequest\x12\'.v1.agent.GetInterventionRequestRequest\x1a\x1d.v1.model.InterventionRequest\"\x00\x12\x65\n\x17GetInterventionResponse\x12(.v1.agent.GetInterventionResponseRequest\x1a\x1e.v1.model.InterventionResponse\"\x00\x12p\n\x17GetStreamsConfiguration\x12(.v1.agent.GetStreamsConfigurationRequest\x1a).v1.agent.GetStreamsConfigurationResponse\"\x00\x12|\n\x1bGetApplicationConfiguration\x12,.v1.agent.GetApplicationConfigurationRequest\x1a-.v1.agent.GetApplicationConfigurationResponse\"\x00\x12^\n\x11GetConfigBlobData\x12\".v1.agent.GetConfigBlobDataRequest\x1a#.v1.agent.GetConfigBlobDataResponse\"\x00\x12j\n\x15GetAgentConfiguration\x12&.v1.agent.GetAgentConfigurationRequest\x1a\'.v1.agent.GetAgentConfigurationResponse\"\x00\x12^\n\x11GetBufferMetadata\x12\".v1.agent.GetBufferMetadataRequest\x1a#.v1.agent.GetBufferMetadataResponse\"\x00\x12X\n\x0fQueryDatapoints\x12 .v1.agent.QueryDatapointsRequest\x1a!.v1.agent.QueryDatapointsResponse\"\x00\x12L\n\x0bQueryEvents\x12\x1c.v1.agent.QueryEventsRequest\x1a\x1d.v1.agent.QueryEventsResponse\"\x00\x12=\n\x06Health\x12\x17.v1.agent.HealthRequest\x1a\x18.v1.agent.HealthResponse\"\x00\x12^\n\x11GetCommandRequest\x12\".v1.agent.GetCommandRequestRequest\x1a#.v1.agent.GetCommandRequestResponse\"\x00\x12r\n\x17GetCommandRequestStream\x12(.v1.agent.GetCommandRequestStreamRequest\x1a).v1.agent.GetCommandRequestStreamResponse\"\x00\x30\x01\x12\x64\n\x13SendCommandResponse\x12$.v1.agent.SendCommandResponseRequest\x1a%.v1.agent.SendCommandResponseResponse\"\x00\x12V\n\x12PostTransformFrame\x12\x18.v1.model.TransformFrame\x1a$.v1.agent.PostTransformFrameResponse\"\x00\x12U\n\x0eSetBaseFrameID\x12\x1f.v1.agent.SetBaseFrameIDRequest\x1a .v1.agent.SetBaseFrameIDResponse\"\x00\x12\x61\n\x12\x43learTransformTree\x12#.v1.agent.ClearTransformTreeRequest\x1a$.v1.agent.ClearTransformTreeResponse\"\x00\x12R\n\rGetTeleopInfo\x12\x1e.v1.agent.GetTeleopInfoRequest\x1a\x1f.v1.agent.GetTeleopInfoResponse\"\x00\x12X\n\x0fPostLanRtcOffer\x12 .v1.agent.PostLanRtcOfferRequest\x1a!.v1.agent.PostLanRtcOfferResponse\"\x00\x12p\n\x17SendOnCustomDataChannel\x12(.v1.agent.SendOnCustomDataChannelRequest\x1a).v1.agent.SendOnCustomDataChannelResponse\"\x00\x12\x61\n\x15PostGenericAPIRequest\x12\x1d.v1.model.GenericAPIDatapoint\x1a\'.v1.agent.PostGenericAPIRequestResponse\"\x00\x12u\n\x1fPostGenericAPIUnbufferedRequest\x12\x1d.v1.model.GenericAPIDatapoint\x1a\x31.v1.agent.PostGenericAPIUnbufferedRequestResponse\"\x00\x42+Z)github.com/FormantIO/genproto/go/v1/agentb\x06proto3'
  ,
  dependencies=[protos_dot_model_dot_v1_dot_datapoint__pb2.DESCRIPTOR,protos_dot_model_dot_v1_dot_intervention__pb2.DESCRIPTOR,protos_dot_model_dot_v1_dot_commands__pb2.DESCRIPTOR,protos_dot_model_dot_v1_dot_config__pb2.DESCRIPTOR,protos_dot_model_dot_v1_dot_math__pb2.DESCRIPTOR,protos_dot_model_dot_v1_dot_event__pb2.DESCRIPTOR,protos_dot_model_dot_v1_dot_health__pb2.DESCRIPTOR,])




_POSTGENERICAPIUNBUFFEREDREQUESTRESPONSE = _descriptor.Descriptor(
  name='PostGenericAPIUnbufferedRequestResponse',
  full_name='v1.agent.PostGenericAPIUnbufferedRequestResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='statusCode', full_name='v1.agent.PostGenericAPIUnbufferedRequestResponse.statusCode', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='responseBody', full_name='v1.agent.PostGenericAPIUnbufferedRequestResponse.responseBody', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=259,
  serialized_end=342,
)


_POSTGENERICAPIREQUESTRESPONSE = _descriptor.Descriptor(
  name='PostGenericAPIRequestResponse',
  full_name='v1.agent.PostGenericAPIRequestResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=344,
  serialized_end=375,
)


_STREAMDATARESPONSE = _descriptor.Descriptor(
  name='StreamDataResponse',
  full_name='v1.agent.StreamDataResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=377,
  serialized_end=397,
)


_POSTDATARESPONSE = _descriptor.Descriptor(
  name='PostDataResponse',
  full_name='v1.agent.PostDataResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=399,
  serialized_end=417,
)


_POSTDATAERROR = _descriptor.Descriptor(
  name='PostDataError',
  full_name='v1.agent.PostDataError',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='index', full_name='v1.agent.PostDataError.index', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='code', full_name='v1.agent.PostDataError.code', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='retryable', full_name='v1.agent.PostDataError.retryable', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='message', full_name='v1.agent.PostDataError.message', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=419,
  serialized_end=499,
)


_POSTDATAMULTIREQUEST = _descriptor.Descriptor(
  name='PostDataMultiRequest',
  full_name='v1.agent.PostDataMultiRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='datapoints', full_name='v1.agent.PostDataMultiRequest.datapoints', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=501,
  serialized_end=564,
)


_POSTDATAMULTIRESPONSE = _descriptor.Descriptor(
  name='PostDataMultiResponse',
  full_name='v1.agent.PostDataMultiResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=566,
  serialized_end=589,
)


_POSTDATAMULTIERROR = _descriptor.Descriptor(
  name='PostDataMultiError',
  full_name='v1.agent.PostDataMultiError',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='errors', full_name='v1.agent.PostDataMultiError.errors', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=591,
  serialized_end=652,
)


_GETINTERVENTIONREQUESTREQUEST = _descriptor.Descriptor(
  name='GetInterventionRequestRequest',
  full_name='v1.agent.GetInterventionRequestRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='v1.agent.GetInterventionRequestRequest.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=654,
  serialized_end=697,
)


_GETINTERVENTIONRESPONSEREQUEST = _descriptor.Descriptor(
  name='GetInterventionResponseRequest',
  full_name='v1.agent.GetInterventionResponseRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='request_id', full_name='v1.agent.GetInterventionResponseRequest.request_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=699,
  serialized_end=751,
)


_GETSTREAMSCONFIGURATIONREQUEST = _descriptor.Descriptor(
  name='GetStreamsConfigurationRequest',
  full_name='v1.agent.GetStreamsConfigurationRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=753,
  serialized_end=785,
)


_GETSTREAMSCONFIGURATIONRESPONSE = _descriptor.Descriptor(
  name='GetStreamsConfigurationResponse',
  full_name='v1.agent.GetStreamsConfigurationResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='streams', full_name='v1.agent.GetStreamsConfigurationResponse.streams', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=787,
  serialized_end=868,
)


_GETAPPLICATIONCONFIGURATIONREQUEST = _descriptor.Descriptor(
  name='GetApplicationConfigurationRequest',
  full_name='v1.agent.GetApplicationConfigurationRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=870,
  serialized_end=906,
)


_GETAPPLICATIONCONFIGURATIONRESPONSE = _descriptor.Descriptor(
  name='GetApplicationConfigurationResponse',
  full_name='v1.agent.GetApplicationConfigurationResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='configuration', full_name='v1.agent.GetApplicationConfigurationResponse.configuration', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=908,
  serialized_end=1004,
)


_GETCONFIGBLOBDATAREQUEST = _descriptor.Descriptor(
  name='GetConfigBlobDataRequest',
  full_name='v1.agent.GetConfigBlobDataRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1006,
  serialized_end=1032,
)


_GETCONFIGBLOBDATARESPONSE = _descriptor.Descriptor(
  name='GetConfigBlobDataResponse',
  full_name='v1.agent.GetConfigBlobDataResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='blob_data', full_name='v1.agent.GetConfigBlobDataResponse.blob_data', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1034,
  serialized_end=1100,
)


_GETAGENTCONFIGURATIONREQUEST = _descriptor.Descriptor(
  name='GetAgentConfigurationRequest',
  full_name='v1.agent.GetAgentConfigurationRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1102,
  serialized_end=1132,
)


_GETAGENTCONFIGURATIONRESPONSE = _descriptor.Descriptor(
  name='GetAgentConfigurationResponse',
  full_name='v1.agent.GetAgentConfigurationResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='configuration', full_name='v1.agent.GetAgentConfigurationResponse.configuration', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1134,
  serialized_end=1218,
)


_GETBUFFERMETADATAREQUEST = _descriptor.Descriptor(
  name='GetBufferMetadataRequest',
  full_name='v1.agent.GetBufferMetadataRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1220,
  serialized_end=1246,
)


_QUERYDATAPOINTSREQUEST = _descriptor.Descriptor(
  name='QueryDatapointsRequest',
  full_name='v1.agent.QueryDatapointsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='stream_name', full_name='v1.agent.QueryDatapointsRequest.stream_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='start', full_name='v1.agent.QueryDatapointsRequest.start', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='end', full_name='v1.agent.QueryDatapointsRequest.end', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='limit', full_name='v1.agent.QueryDatapointsRequest.limit', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='offset', full_name='v1.agent.QueryDatapointsRequest.offset', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1248,
  serialized_end=1352,
)


_QUERYDATAPOINTSRESPONSE = _descriptor.Descriptor(
  name='QueryDatapointsResponse',
  full_name='v1.agent.QueryDatapointsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='results', full_name='v1.agent.QueryDatapointsResponse.results', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1354,
  serialized_end=1417,
)


_QUERYEVENTSREQUEST = _descriptor.Descriptor(
  name='QueryEventsRequest',
  full_name='v1.agent.QueryEventsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start', full_name='v1.agent.QueryEventsRequest.start', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='end', full_name='v1.agent.QueryEventsRequest.end', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='limit', full_name='v1.agent.QueryEventsRequest.limit', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='offset', full_name='v1.agent.QueryEventsRequest.offset', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1419,
  serialized_end=1498,
)


_QUERYEVENTSRESPONSE = _descriptor.Descriptor(
  name='QueryEventsResponse',
  full_name='v1.agent.QueryEventsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='results', full_name='v1.agent.QueryEventsResponse.results', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1500,
  serialized_end=1555,
)


_GETBUFFERMETADATARESPONSE = _descriptor.Descriptor(
  name='GetBufferMetadataResponse',
  full_name='v1.agent.GetBufferMetadataResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='connections', full_name='v1.agent.GetBufferMetadataResponse.connections', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1557,
  serialized_end=1631,
)


_HEALTHREQUEST = _descriptor.Descriptor(
  name='HealthRequest',
  full_name='v1.agent.HealthRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1633,
  serialized_end=1648,
)


_HEALTHRESPONSE = _descriptor.Descriptor(
  name='HealthResponse',
  full_name='v1.agent.HealthResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1650,
  serialized_end=1666,
)


_GETCOMMANDREQUESTREQUEST = _descriptor.Descriptor(
  name='GetCommandRequestRequest',
  full_name='v1.agent.GetCommandRequestRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='command_filter', full_name='v1.agent.GetCommandRequestRequest.command_filter', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1668,
  serialized_end=1718,
)


_GETCOMMANDREQUESTRESPONSE = _descriptor.Descriptor(
  name='GetCommandRequestResponse',
  full_name='v1.agent.GetCommandRequestResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='request', full_name='v1.agent.GetCommandRequestResponse.request', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1720,
  serialized_end=1790,
)


_SENDCOMMANDRESPONSEREQUEST = _descriptor.Descriptor(
  name='SendCommandResponseRequest',
  full_name='v1.agent.SendCommandResponseRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='response', full_name='v1.agent.SendCommandResponseRequest.response', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1792,
  serialized_end=1865,
)


_SENDCOMMANDRESPONSERESPONSE = _descriptor.Descriptor(
  name='SendCommandResponseResponse',
  full_name='v1.agent.SendCommandResponseResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1867,
  serialized_end=1896,
)


_GETCOMMANDREQUESTSTREAMREQUEST = _descriptor.Descriptor(
  name='GetCommandRequestStreamRequest',
  full_name='v1.agent.GetCommandRequestStreamRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='command_filter', full_name='v1.agent.GetCommandRequestStreamRequest.command_filter', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1898,
  serialized_end=1954,
)


_GETCOMMANDREQUESTSTREAMRESPONSE = _descriptor.Descriptor(
  name='GetCommandRequestStreamResponse',
  full_name='v1.agent.GetCommandRequestStreamResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='request', full_name='v1.agent.GetCommandRequestStreamResponse.request', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1956,
  serialized_end=2032,
)


_GETTELEOPCONTROLDATASTREAMREQUEST = _descriptor.Descriptor(
  name='GetTeleopControlDataStreamRequest',
  full_name='v1.agent.GetTeleopControlDataStreamRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='stream_filter', full_name='v1.agent.GetTeleopControlDataStreamRequest.stream_filter', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2034,
  serialized_end=2092,
)


_GETTELEOPCONTROLDATASTREAMRESPONSE = _descriptor.Descriptor(
  name='GetTeleopControlDataStreamResponse',
  full_name='v1.agent.GetTeleopControlDataStreamResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='control_datapoint', full_name='v1.agent.GetTeleopControlDataStreamResponse.control_datapoint', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2094,
  serialized_end=2185,
)


_GETTELEOPHEARTBEATSTREAMREQUEST = _descriptor.Descriptor(
  name='GetTeleopHeartbeatStreamRequest',
  full_name='v1.agent.GetTeleopHeartbeatStreamRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2187,
  serialized_end=2220,
)


_GETTELEOPHEARTBEATSTREAMRESPONSE = _descriptor.Descriptor(
  name='GetTeleopHeartbeatStreamResponse',
  full_name='v1.agent.GetTeleopHeartbeatStreamResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='peer_id', full_name='v1.agent.GetTeleopHeartbeatStreamResponse.peer_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_disconnect', full_name='v1.agent.GetTeleopHeartbeatStreamResponse.is_disconnect', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='session_type', full_name='v1.agent.GetTeleopHeartbeatStreamResponse.session_type', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2222,
  serialized_end=2318,
)


_GETTELEMETRYLISTENERSTREAMREQUEST = _descriptor.Descriptor(
  name='GetTelemetryListenerStreamRequest',
  full_name='v1.agent.GetTelemetryListenerStreamRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='stream_filter', full_name='v1.agent.GetTelemetryListenerStreamRequest.stream_filter', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2320,
  serialized_end=2378,
)


_GETTELEMETRYLISTENERSTREAMRESPONSE = _descriptor.Descriptor(
  name='GetTelemetryListenerStreamResponse',
  full_name='v1.agent.GetTelemetryListenerStreamResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='datapoint', full_name='v1.agent.GetTelemetryListenerStreamResponse.datapoint', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2380,
  serialized_end=2456,
)


_POSTTRANSFORMFRAMERESPONSE = _descriptor.Descriptor(
  name='PostTransformFrameResponse',
  full_name='v1.agent.PostTransformFrameResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2458,
  serialized_end=2486,
)


_SETBASEFRAMEIDREQUEST = _descriptor.Descriptor(
  name='SetBaseFrameIDRequest',
  full_name='v1.agent.SetBaseFrameIDRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='v1.agent.SetBaseFrameIDRequest.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2488,
  serialized_end=2523,
)


_SETBASEFRAMEIDRESPONSE = _descriptor.Descriptor(
  name='SetBaseFrameIDResponse',
  full_name='v1.agent.SetBaseFrameIDResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2525,
  serialized_end=2549,
)


_CLEARTRANSFORMTREEREQUEST = _descriptor.Descriptor(
  name='ClearTransformTreeRequest',
  full_name='v1.agent.ClearTransformTreeRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2551,
  serialized_end=2578,
)


_CLEARTRANSFORMTREERESPONSE = _descriptor.Descriptor(
  name='ClearTransformTreeResponse',
  full_name='v1.agent.ClearTransformTreeResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2580,
  serialized_end=2608,
)


_CREATEEVENTREQUEST = _descriptor.Descriptor(
  name='CreateEventRequest',
  full_name='v1.agent.CreateEventRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='event', full_name='v1.agent.CreateEventRequest.event', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2610,
  serialized_end=2662,
)


_CREATEEVENTRESPONSE = _descriptor.Descriptor(
  name='CreateEventResponse',
  full_name='v1.agent.CreateEventResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2664,
  serialized_end=2685,
)


_CREATEEVENTERROR = _descriptor.Descriptor(
  name='CreateEventError',
  full_name='v1.agent.CreateEventError',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='retryable', full_name='v1.agent.CreateEventError.retryable', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2687,
  serialized_end=2724,
)


_GETTELEOPINFOREQUEST = _descriptor.Descriptor(
  name='GetTeleopInfoRequest',
  full_name='v1.agent.GetTeleopInfoRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2726,
  serialized_end=2748,
)


_GETTELEOPINFORESPONSE = _descriptor.Descriptor(
  name='GetTeleopInfoResponse',
  full_name='v1.agent.GetTeleopInfoResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='connection_count', full_name='v1.agent.GetTeleopInfoResponse.connection_count', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2750,
  serialized_end=2799,
)


_POSTLANRTCOFFERREQUEST = _descriptor.Descriptor(
  name='PostLanRtcOfferRequest',
  full_name='v1.agent.PostLanRtcOfferRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='offer', full_name='v1.agent.PostLanRtcOfferRequest.offer', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2801,
  serialized_end=2840,
)


_POSTLANRTCOFFERRESPONSE = _descriptor.Descriptor(
  name='PostLanRtcOfferResponse',
  full_name='v1.agent.PostLanRtcOfferResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='answer', full_name='v1.agent.PostLanRtcOfferResponse.answer', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2842,
  serialized_end=2883,
)


_SENDONCUSTOMDATACHANNELREQUEST = _descriptor.Descriptor(
  name='SendOnCustomDataChannelRequest',
  full_name='v1.agent.SendOnCustomDataChannelRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='channel_name', full_name='v1.agent.SendOnCustomDataChannelRequest.channel_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='payload', full_name='v1.agent.SendOnCustomDataChannelRequest.payload', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2885,
  serialized_end=2956,
)


_SENDONCUSTOMDATACHANNELRESPONSE = _descriptor.Descriptor(
  name='SendOnCustomDataChannelResponse',
  full_name='v1.agent.SendOnCustomDataChannelResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2958,
  serialized_end=2991,
)


_GETCUSTOMDATACHANNELMESSAGESTREAMREQUEST = _descriptor.Descriptor(
  name='GetCustomDataChannelMessageStreamRequest',
  full_name='v1.agent.GetCustomDataChannelMessageStreamRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='channel_name_filter', full_name='v1.agent.GetCustomDataChannelMessageStreamRequest.channel_name_filter', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2993,
  serialized_end=3064,
)


_GETCUSTOMDATACHANNELMESSAGESTREAMRESPONSE = _descriptor.Descriptor(
  name='GetCustomDataChannelMessageStreamResponse',
  full_name='v1.agent.GetCustomDataChannelMessageStreamResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='peer_id', full_name='v1.agent.GetCustomDataChannelMessageStreamResponse.peer_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='channel_name', full_name='v1.agent.GetCustomDataChannelMessageStreamResponse.channel_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='payload', full_name='v1.agent.GetCustomDataChannelMessageStreamResponse.payload', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3066,
  serialized_end=3165,
)

_POSTDATAMULTIREQUEST.fields_by_name['datapoints'].message_type = protos_dot_model_dot_v1_dot_datapoint__pb2._DATAPOINT
_POSTDATAMULTIERROR.fields_by_name['errors'].message_type = _POSTDATAERROR
_GETSTREAMSCONFIGURATIONRESPONSE.fields_by_name['streams'].message_type = protos_dot_model_dot_v1_dot_config__pb2._STREAMCONFIGURATION
_GETAPPLICATIONCONFIGURATIONRESPONSE.fields_by_name['configuration'].message_type = protos_dot_model_dot_v1_dot_config__pb2._APPLICATIONCONFIGURATION
_GETCONFIGBLOBDATARESPONSE.fields_by_name['blob_data'].message_type = protos_dot_model_dot_v1_dot_config__pb2._BLOBDATA
_GETAGENTCONFIGURATIONRESPONSE.fields_by_name['configuration'].message_type = protos_dot_model_dot_v1_dot_config__pb2._AGENTCONFIGURATION
_QUERYDATAPOINTSRESPONSE.fields_by_name['results'].message_type = protos_dot_model_dot_v1_dot_datapoint__pb2._DATAPOINT
_QUERYEVENTSRESPONSE.fields_by_name['results'].message_type = protos_dot_model_dot_v1_dot_event__pb2._EVENT
_GETBUFFERMETADATARESPONSE.fields_by_name['connections'].message_type = protos_dot_model_dot_v1_dot_health__pb2._BUFFERMETADATA
_GETCOMMANDREQUESTRESPONSE.fields_by_name['request'].message_type = protos_dot_model_dot_v1_dot_commands__pb2._COMMANDREQUEST
_SENDCOMMANDRESPONSEREQUEST.fields_by_name['response'].message_type = protos_dot_model_dot_v1_dot_commands__pb2._COMMANDRESPONSE
_GETCOMMANDREQUESTSTREAMRESPONSE.fields_by_name['request'].message_type = protos_dot_model_dot_v1_dot_commands__pb2._COMMANDREQUEST
_GETTELEOPCONTROLDATASTREAMRESPONSE.fields_by_name['control_datapoint'].message_type = protos_dot_model_dot_v1_dot_datapoint__pb2._CONTROLDATAPOINT
_GETTELEMETRYLISTENERSTREAMRESPONSE.fields_by_name['datapoint'].message_type = protos_dot_model_dot_v1_dot_datapoint__pb2._DATAPOINT
_CREATEEVENTREQUEST.fields_by_name['event'].message_type = protos_dot_model_dot_v1_dot_event__pb2._EVENT
DESCRIPTOR.message_types_by_name['PostGenericAPIUnbufferedRequestResponse'] = _POSTGENERICAPIUNBUFFEREDREQUESTRESPONSE
DESCRIPTOR.message_types_by_name['PostGenericAPIRequestResponse'] = _POSTGENERICAPIREQUESTRESPONSE
DESCRIPTOR.message_types_by_name['StreamDataResponse'] = _STREAMDATARESPONSE
DESCRIPTOR.message_types_by_name['PostDataResponse'] = _POSTDATARESPONSE
DESCRIPTOR.message_types_by_name['PostDataError'] = _POSTDATAERROR
DESCRIPTOR.message_types_by_name['PostDataMultiRequest'] = _POSTDATAMULTIREQUEST
DESCRIPTOR.message_types_by_name['PostDataMultiResponse'] = _POSTDATAMULTIRESPONSE
DESCRIPTOR.message_types_by_name['PostDataMultiError'] = _POSTDATAMULTIERROR
DESCRIPTOR.message_types_by_name['GetInterventionRequestRequest'] = _GETINTERVENTIONREQUESTREQUEST
DESCRIPTOR.message_types_by_name['GetInterventionResponseRequest'] = _GETINTERVENTIONRESPONSEREQUEST
DESCRIPTOR.message_types_by_name['GetStreamsConfigurationRequest'] = _GETSTREAMSCONFIGURATIONREQUEST
DESCRIPTOR.message_types_by_name['GetStreamsConfigurationResponse'] = _GETSTREAMSCONFIGURATIONRESPONSE
DESCRIPTOR.message_types_by_name['GetApplicationConfigurationRequest'] = _GETAPPLICATIONCONFIGURATIONREQUEST
DESCRIPTOR.message_types_by_name['GetApplicationConfigurationResponse'] = _GETAPPLICATIONCONFIGURATIONRESPONSE
DESCRIPTOR.message_types_by_name['GetConfigBlobDataRequest'] = _GETCONFIGBLOBDATAREQUEST
DESCRIPTOR.message_types_by_name['GetConfigBlobDataResponse'] = _GETCONFIGBLOBDATARESPONSE
DESCRIPTOR.message_types_by_name['GetAgentConfigurationRequest'] = _GETAGENTCONFIGURATIONREQUEST
DESCRIPTOR.message_types_by_name['GetAgentConfigurationResponse'] = _GETAGENTCONFIGURATIONRESPONSE
DESCRIPTOR.message_types_by_name['GetBufferMetadataRequest'] = _GETBUFFERMETADATAREQUEST
DESCRIPTOR.message_types_by_name['QueryDatapointsRequest'] = _QUERYDATAPOINTSREQUEST
DESCRIPTOR.message_types_by_name['QueryDatapointsResponse'] = _QUERYDATAPOINTSRESPONSE
DESCRIPTOR.message_types_by_name['QueryEventsRequest'] = _QUERYEVENTSREQUEST
DESCRIPTOR.message_types_by_name['QueryEventsResponse'] = _QUERYEVENTSRESPONSE
DESCRIPTOR.message_types_by_name['GetBufferMetadataResponse'] = _GETBUFFERMETADATARESPONSE
DESCRIPTOR.message_types_by_name['HealthRequest'] = _HEALTHREQUEST
DESCRIPTOR.message_types_by_name['HealthResponse'] = _HEALTHRESPONSE
DESCRIPTOR.message_types_by_name['GetCommandRequestRequest'] = _GETCOMMANDREQUESTREQUEST
DESCRIPTOR.message_types_by_name['GetCommandRequestResponse'] = _GETCOMMANDREQUESTRESPONSE
DESCRIPTOR.message_types_by_name['SendCommandResponseRequest'] = _SENDCOMMANDRESPONSEREQUEST
DESCRIPTOR.message_types_by_name['SendCommandResponseResponse'] = _SENDCOMMANDRESPONSERESPONSE
DESCRIPTOR.message_types_by_name['GetCommandRequestStreamRequest'] = _GETCOMMANDREQUESTSTREAMREQUEST
DESCRIPTOR.message_types_by_name['GetCommandRequestStreamResponse'] = _GETCOMMANDREQUESTSTREAMRESPONSE
DESCRIPTOR.message_types_by_name['GetTeleopControlDataStreamRequest'] = _GETTELEOPCONTROLDATASTREAMREQUEST
DESCRIPTOR.message_types_by_name['GetTeleopControlDataStreamResponse'] = _GETTELEOPCONTROLDATASTREAMRESPONSE
DESCRIPTOR.message_types_by_name['GetTeleopHeartbeatStreamRequest'] = _GETTELEOPHEARTBEATSTREAMREQUEST
DESCRIPTOR.message_types_by_name['GetTeleopHeartbeatStreamResponse'] = _GETTELEOPHEARTBEATSTREAMRESPONSE
DESCRIPTOR.message_types_by_name['GetTelemetryListenerStreamRequest'] = _GETTELEMETRYLISTENERSTREAMREQUEST
DESCRIPTOR.message_types_by_name['GetTelemetryListenerStreamResponse'] = _GETTELEMETRYLISTENERSTREAMRESPONSE
DESCRIPTOR.message_types_by_name['PostTransformFrameResponse'] = _POSTTRANSFORMFRAMERESPONSE
DESCRIPTOR.message_types_by_name['SetBaseFrameIDRequest'] = _SETBASEFRAMEIDREQUEST
DESCRIPTOR.message_types_by_name['SetBaseFrameIDResponse'] = _SETBASEFRAMEIDRESPONSE
DESCRIPTOR.message_types_by_name['ClearTransformTreeRequest'] = _CLEARTRANSFORMTREEREQUEST
DESCRIPTOR.message_types_by_name['ClearTransformTreeResponse'] = _CLEARTRANSFORMTREERESPONSE
DESCRIPTOR.message_types_by_name['CreateEventRequest'] = _CREATEEVENTREQUEST
DESCRIPTOR.message_types_by_name['CreateEventResponse'] = _CREATEEVENTRESPONSE
DESCRIPTOR.message_types_by_name['CreateEventError'] = _CREATEEVENTERROR
DESCRIPTOR.message_types_by_name['GetTeleopInfoRequest'] = _GETTELEOPINFOREQUEST
DESCRIPTOR.message_types_by_name['GetTeleopInfoResponse'] = _GETTELEOPINFORESPONSE
DESCRIPTOR.message_types_by_name['PostLanRtcOfferRequest'] = _POSTLANRTCOFFERREQUEST
DESCRIPTOR.message_types_by_name['PostLanRtcOfferResponse'] = _POSTLANRTCOFFERRESPONSE
DESCRIPTOR.message_types_by_name['SendOnCustomDataChannelRequest'] = _SENDONCUSTOMDATACHANNELREQUEST
DESCRIPTOR.message_types_by_name['SendOnCustomDataChannelResponse'] = _SENDONCUSTOMDATACHANNELRESPONSE
DESCRIPTOR.message_types_by_name['GetCustomDataChannelMessageStreamRequest'] = _GETCUSTOMDATACHANNELMESSAGESTREAMREQUEST
DESCRIPTOR.message_types_by_name['GetCustomDataChannelMessageStreamResponse'] = _GETCUSTOMDATACHANNELMESSAGESTREAMRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

PostGenericAPIUnbufferedRequestResponse = _reflection.GeneratedProtocolMessageType('PostGenericAPIUnbufferedRequestResponse', (_message.Message,), {
  'DESCRIPTOR' : _POSTGENERICAPIUNBUFFEREDREQUESTRESPONSE,
  '__module__' : 'protos.agent.v1.agent_pb2'
  # @@protoc_insertion_point(class_scope:v1.agent.PostGenericAPIUnbufferedRequestResponse)
  })
_sym_db.RegisterMessage(PostGenericAPIUnbufferedRequestResponse)

PostGenericAPIRequestResponse = _reflection.GeneratedProtocolMessageType('PostGenericAPIRequestResponse', (_message.Message,), {
  'DESCRIPTOR' : _POSTGENERICAPIREQUESTRESPONSE,
  '__module__' : 'protos.agent.v1.agent_pb2'
  # @@protoc_insertion_point(class_scope:v1.agent.PostGenericAPIRequestResponse)
  })
_sym_db.RegisterMessage(PostGenericAPIRequestResponse)

StreamDataResponse = _reflection.GeneratedProtocolMessageType('StreamDataResponse', (_message.Message,), {
  'DESCRIPTOR' : _STREAMDATARESPONSE,
  '__module__' : 'protos.agent.v1.agent_pb2'
  # @@protoc_insertion_point(class_scope:v1.agent.StreamDataResponse)
  })
_sym_db.RegisterMessage(StreamDataResponse)

PostDataResponse = _reflection.GeneratedProtocolMessageType('PostDataResponse', (_message.Message,), {
  'DESCRIPTOR' : _POSTDATARESPONSE,
  '__module__' : 'protos.agent.v1.agent_pb2'
  # @@protoc_insertion_point(class_scope:v1.agent.PostDataResponse)
  })
_sym_db.RegisterMessage(PostDataResponse)

PostDataError = _reflection.GeneratedProtocolMessageType('PostDataError', (_message.Message,), {
  'DESCRIPTOR' : _POSTDATAERROR,
  '__module__' : 'protos.agent.v1.agent_pb2'
  # @@protoc_insertion_point(class_scope:v1.agent.PostDataError)
  })
_sym_db.RegisterMessage(PostDataError)

PostDataMultiRequest = _reflection.GeneratedProtocolMessageType('PostDataMultiRequest', (_message.Message,), {
  'DESCRIPTOR' : _POSTDATAMULTIREQUEST,
  '__module__' : 'protos.agent.v1.agent_pb2'
  # @@protoc_insertion_point(class_scope:v1.agent.PostDataMultiRequest)
  })
_sym_db.RegisterMessage(PostDataMultiRequest)

PostDataMultiResponse = _reflection.GeneratedProtocolMessageType('PostDataMultiResponse', (_message.Message,), {
  'DESCRIPTOR' : _POSTDATAMULTIRESPONSE,
  '__module__' : 'protos.agent.v1.agent_pb2'
  # @@protoc_insertion_point(class_scope:v1.agent.PostDataMultiResponse)
  })
_sym_db.RegisterMessage(PostDataMultiResponse)

PostDataMultiError = _reflection.GeneratedProtocolMessageType('PostDataMultiError', (_message.Message,), {
  'DESCRIPTOR' : _POSTDATAMULTIERROR,
  '__module__' : 'protos.agent.v1.agent_pb2'
  # @@protoc_insertion_point(class_scope:v1.agent.PostDataMultiError)
  })
_sym_db.RegisterMessage(PostDataMultiError)

GetInterventionRequestRequest = _reflection.GeneratedProtocolMessageType('GetInterventionRequestRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETINTERVENTIONREQUESTREQUEST,
  '__module__' : 'protos.agent.v1.agent_pb2'
  # @@protoc_insertion_point(class_scope:v1.agent.GetInterventionRequestRequest)
  })
_sym_db.RegisterMessage(GetInterventionRequestRequest)

GetInterventionResponseRequest = _reflection.GeneratedProtocolMessageType('GetInterventionResponseRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETINTERVENTIONRESPONSEREQUEST,
  '__module__' : 'protos.agent.v1.agent_pb2'
  # @@protoc_insertion_point(class_scope:v1.agent.GetInterventionResponseRequest)
  })
_sym_db.RegisterMessage(GetInterventionResponseRequest)

GetStreamsConfigurationRequest = _reflection.GeneratedProtocolMessageType('GetStreamsConfigurationRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETSTREAMSCONFIGURATIONREQUEST,
  '__module__' : 'protos.agent.v1.agent_pb2'
  # @@protoc_insertion_point(class_scope:v1.agent.GetStreamsConfigurationRequest)
  })
_sym_db.RegisterMessage(GetStreamsConfigurationRequest)

GetStreamsConfigurationResponse = _reflection.GeneratedProtocolMessageType('GetStreamsConfigurationResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETSTREAMSCONFIGURATIONRESPONSE,
  '__module__' : 'protos.agent.v1.agent_pb2'
  # @@protoc_insertion_point(class_scope:v1.agent.GetStreamsConfigurationResponse)
  })
_sym_db.RegisterMessage(GetStreamsConfigurationResponse)

GetApplicationConfigurationRequest = _reflection.GeneratedProtocolMessageType('GetApplicationConfigurationRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETAPPLICATIONCONFIGURATIONREQUEST,
  '__module__' : 'protos.agent.v1.agent_pb2'
  # @@protoc_insertion_point(class_scope:v1.agent.GetApplicationConfigurationRequest)
  })
_sym_db.RegisterMessage(GetApplicationConfigurationRequest)

GetApplicationConfigurationResponse = _reflection.GeneratedProtocolMessageType('GetApplicationConfigurationResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETAPPLICATIONCONFIGURATIONRESPONSE,
  '__module__' : 'protos.agent.v1.agent_pb2'
  # @@protoc_insertion_point(class_scope:v1.agent.GetApplicationConfigurationResponse)
  })
_sym_db.RegisterMessage(GetApplicationConfigurationResponse)

GetConfigBlobDataRequest = _reflection.GeneratedProtocolMessageType('GetConfigBlobDataRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETCONFIGBLOBDATAREQUEST,
  '__module__' : 'protos.agent.v1.agent_pb2'
  # @@protoc_insertion_point(class_scope:v1.agent.GetConfigBlobDataRequest)
  })
_sym_db.RegisterMessage(GetConfigBlobDataRequest)

GetConfigBlobDataResponse = _reflection.GeneratedProtocolMessageType('GetConfigBlobDataResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETCONFIGBLOBDATARESPONSE,
  '__module__' : 'protos.agent.v1.agent_pb2'
  # @@protoc_insertion_point(class_scope:v1.agent.GetConfigBlobDataResponse)
  })
_sym_db.RegisterMessage(GetConfigBlobDataResponse)

GetAgentConfigurationRequest = _reflection.GeneratedProtocolMessageType('GetAgentConfigurationRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETAGENTCONFIGURATIONREQUEST,
  '__module__' : 'protos.agent.v1.agent_pb2'
  # @@protoc_insertion_point(class_scope:v1.agent.GetAgentConfigurationRequest)
  })
_sym_db.RegisterMessage(GetAgentConfigurationRequest)

GetAgentConfigurationResponse = _reflection.GeneratedProtocolMessageType('GetAgentConfigurationResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETAGENTCONFIGURATIONRESPONSE,
  '__module__' : 'protos.agent.v1.agent_pb2'
  # @@protoc_insertion_point(class_scope:v1.agent.GetAgentConfigurationResponse)
  })
_sym_db.RegisterMessage(GetAgentConfigurationResponse)

GetBufferMetadataRequest = _reflection.GeneratedProtocolMessageType('GetBufferMetadataRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETBUFFERMETADATAREQUEST,
  '__module__' : 'protos.agent.v1.agent_pb2'
  # @@protoc_insertion_point(class_scope:v1.agent.GetBufferMetadataRequest)
  })
_sym_db.RegisterMessage(GetBufferMetadataRequest)

QueryDatapointsRequest = _reflection.GeneratedProtocolMessageType('QueryDatapointsRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYDATAPOINTSREQUEST,
  '__module__' : 'protos.agent.v1.agent_pb2'
  # @@protoc_insertion_point(class_scope:v1.agent.QueryDatapointsRequest)
  })
_sym_db.RegisterMessage(QueryDatapointsRequest)

QueryDatapointsResponse = _reflection.GeneratedProtocolMessageType('QueryDatapointsResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYDATAPOINTSRESPONSE,
  '__module__' : 'protos.agent.v1.agent_pb2'
  # @@protoc_insertion_point(class_scope:v1.agent.QueryDatapointsResponse)
  })
_sym_db.RegisterMessage(QueryDatapointsResponse)

QueryEventsRequest = _reflection.GeneratedProtocolMessageType('QueryEventsRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYEVENTSREQUEST,
  '__module__' : 'protos.agent.v1.agent_pb2'
  # @@protoc_insertion_point(class_scope:v1.agent.QueryEventsRequest)
  })
_sym_db.RegisterMessage(QueryEventsRequest)

QueryEventsResponse = _reflection.GeneratedProtocolMessageType('QueryEventsResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYEVENTSRESPONSE,
  '__module__' : 'protos.agent.v1.agent_pb2'
  # @@protoc_insertion_point(class_scope:v1.agent.QueryEventsResponse)
  })
_sym_db.RegisterMessage(QueryEventsResponse)

GetBufferMetadataResponse = _reflection.GeneratedProtocolMessageType('GetBufferMetadataResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETBUFFERMETADATARESPONSE,
  '__module__' : 'protos.agent.v1.agent_pb2'
  # @@protoc_insertion_point(class_scope:v1.agent.GetBufferMetadataResponse)
  })
_sym_db.RegisterMessage(GetBufferMetadataResponse)

HealthRequest = _reflection.GeneratedProtocolMessageType('HealthRequest', (_message.Message,), {
  'DESCRIPTOR' : _HEALTHREQUEST,
  '__module__' : 'protos.agent.v1.agent_pb2'
  # @@protoc_insertion_point(class_scope:v1.agent.HealthRequest)
  })
_sym_db.RegisterMessage(HealthRequest)

HealthResponse = _reflection.GeneratedProtocolMessageType('HealthResponse', (_message.Message,), {
  'DESCRIPTOR' : _HEALTHRESPONSE,
  '__module__' : 'protos.agent.v1.agent_pb2'
  # @@protoc_insertion_point(class_scope:v1.agent.HealthResponse)
  })
_sym_db.RegisterMessage(HealthResponse)

GetCommandRequestRequest = _reflection.GeneratedProtocolMessageType('GetCommandRequestRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETCOMMANDREQUESTREQUEST,
  '__module__' : 'protos.agent.v1.agent_pb2'
  # @@protoc_insertion_point(class_scope:v1.agent.GetCommandRequestRequest)
  })
_sym_db.RegisterMessage(GetCommandRequestRequest)

GetCommandRequestResponse = _reflection.GeneratedProtocolMessageType('GetCommandRequestResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETCOMMANDREQUESTRESPONSE,
  '__module__' : 'protos.agent.v1.agent_pb2'
  # @@protoc_insertion_point(class_scope:v1.agent.GetCommandRequestResponse)
  })
_sym_db.RegisterMessage(GetCommandRequestResponse)

SendCommandResponseRequest = _reflection.GeneratedProtocolMessageType('SendCommandResponseRequest', (_message.Message,), {
  'DESCRIPTOR' : _SENDCOMMANDRESPONSEREQUEST,
  '__module__' : 'protos.agent.v1.agent_pb2'
  # @@protoc_insertion_point(class_scope:v1.agent.SendCommandResponseRequest)
  })
_sym_db.RegisterMessage(SendCommandResponseRequest)

SendCommandResponseResponse = _reflection.GeneratedProtocolMessageType('SendCommandResponseResponse', (_message.Message,), {
  'DESCRIPTOR' : _SENDCOMMANDRESPONSERESPONSE,
  '__module__' : 'protos.agent.v1.agent_pb2'
  # @@protoc_insertion_point(class_scope:v1.agent.SendCommandResponseResponse)
  })
_sym_db.RegisterMessage(SendCommandResponseResponse)

GetCommandRequestStreamRequest = _reflection.GeneratedProtocolMessageType('GetCommandRequestStreamRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETCOMMANDREQUESTSTREAMREQUEST,
  '__module__' : 'protos.agent.v1.agent_pb2'
  # @@protoc_insertion_point(class_scope:v1.agent.GetCommandRequestStreamRequest)
  })
_sym_db.RegisterMessage(GetCommandRequestStreamRequest)

GetCommandRequestStreamResponse = _reflection.GeneratedProtocolMessageType('GetCommandRequestStreamResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETCOMMANDREQUESTSTREAMRESPONSE,
  '__module__' : 'protos.agent.v1.agent_pb2'
  # @@protoc_insertion_point(class_scope:v1.agent.GetCommandRequestStreamResponse)
  })
_sym_db.RegisterMessage(GetCommandRequestStreamResponse)

GetTeleopControlDataStreamRequest = _reflection.GeneratedProtocolMessageType('GetTeleopControlDataStreamRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETTELEOPCONTROLDATASTREAMREQUEST,
  '__module__' : 'protos.agent.v1.agent_pb2'
  # @@protoc_insertion_point(class_scope:v1.agent.GetTeleopControlDataStreamRequest)
  })
_sym_db.RegisterMessage(GetTeleopControlDataStreamRequest)

GetTeleopControlDataStreamResponse = _reflection.GeneratedProtocolMessageType('GetTeleopControlDataStreamResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETTELEOPCONTROLDATASTREAMRESPONSE,
  '__module__' : 'protos.agent.v1.agent_pb2'
  # @@protoc_insertion_point(class_scope:v1.agent.GetTeleopControlDataStreamResponse)
  })
_sym_db.RegisterMessage(GetTeleopControlDataStreamResponse)

GetTeleopHeartbeatStreamRequest = _reflection.GeneratedProtocolMessageType('GetTeleopHeartbeatStreamRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETTELEOPHEARTBEATSTREAMREQUEST,
  '__module__' : 'protos.agent.v1.agent_pb2'
  # @@protoc_insertion_point(class_scope:v1.agent.GetTeleopHeartbeatStreamRequest)
  })
_sym_db.RegisterMessage(GetTeleopHeartbeatStreamRequest)

GetTeleopHeartbeatStreamResponse = _reflection.GeneratedProtocolMessageType('GetTeleopHeartbeatStreamResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETTELEOPHEARTBEATSTREAMRESPONSE,
  '__module__' : 'protos.agent.v1.agent_pb2'
  # @@protoc_insertion_point(class_scope:v1.agent.GetTeleopHeartbeatStreamResponse)
  })
_sym_db.RegisterMessage(GetTeleopHeartbeatStreamResponse)

GetTelemetryListenerStreamRequest = _reflection.GeneratedProtocolMessageType('GetTelemetryListenerStreamRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETTELEMETRYLISTENERSTREAMREQUEST,
  '__module__' : 'protos.agent.v1.agent_pb2'
  # @@protoc_insertion_point(class_scope:v1.agent.GetTelemetryListenerStreamRequest)
  })
_sym_db.RegisterMessage(GetTelemetryListenerStreamRequest)

GetTelemetryListenerStreamResponse = _reflection.GeneratedProtocolMessageType('GetTelemetryListenerStreamResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETTELEMETRYLISTENERSTREAMRESPONSE,
  '__module__' : 'protos.agent.v1.agent_pb2'
  # @@protoc_insertion_point(class_scope:v1.agent.GetTelemetryListenerStreamResponse)
  })
_sym_db.RegisterMessage(GetTelemetryListenerStreamResponse)

PostTransformFrameResponse = _reflection.GeneratedProtocolMessageType('PostTransformFrameResponse', (_message.Message,), {
  'DESCRIPTOR' : _POSTTRANSFORMFRAMERESPONSE,
  '__module__' : 'protos.agent.v1.agent_pb2'
  # @@protoc_insertion_point(class_scope:v1.agent.PostTransformFrameResponse)
  })
_sym_db.RegisterMessage(PostTransformFrameResponse)

SetBaseFrameIDRequest = _reflection.GeneratedProtocolMessageType('SetBaseFrameIDRequest', (_message.Message,), {
  'DESCRIPTOR' : _SETBASEFRAMEIDREQUEST,
  '__module__' : 'protos.agent.v1.agent_pb2'
  # @@protoc_insertion_point(class_scope:v1.agent.SetBaseFrameIDRequest)
  })
_sym_db.RegisterMessage(SetBaseFrameIDRequest)

SetBaseFrameIDResponse = _reflection.GeneratedProtocolMessageType('SetBaseFrameIDResponse', (_message.Message,), {
  'DESCRIPTOR' : _SETBASEFRAMEIDRESPONSE,
  '__module__' : 'protos.agent.v1.agent_pb2'
  # @@protoc_insertion_point(class_scope:v1.agent.SetBaseFrameIDResponse)
  })
_sym_db.RegisterMessage(SetBaseFrameIDResponse)

ClearTransformTreeRequest = _reflection.GeneratedProtocolMessageType('ClearTransformTreeRequest', (_message.Message,), {
  'DESCRIPTOR' : _CLEARTRANSFORMTREEREQUEST,
  '__module__' : 'protos.agent.v1.agent_pb2'
  # @@protoc_insertion_point(class_scope:v1.agent.ClearTransformTreeRequest)
  })
_sym_db.RegisterMessage(ClearTransformTreeRequest)

ClearTransformTreeResponse = _reflection.GeneratedProtocolMessageType('ClearTransformTreeResponse', (_message.Message,), {
  'DESCRIPTOR' : _CLEARTRANSFORMTREERESPONSE,
  '__module__' : 'protos.agent.v1.agent_pb2'
  # @@protoc_insertion_point(class_scope:v1.agent.ClearTransformTreeResponse)
  })
_sym_db.RegisterMessage(ClearTransformTreeResponse)

CreateEventRequest = _reflection.GeneratedProtocolMessageType('CreateEventRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEEVENTREQUEST,
  '__module__' : 'protos.agent.v1.agent_pb2'
  # @@protoc_insertion_point(class_scope:v1.agent.CreateEventRequest)
  })
_sym_db.RegisterMessage(CreateEventRequest)

CreateEventResponse = _reflection.GeneratedProtocolMessageType('CreateEventResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEEVENTRESPONSE,
  '__module__' : 'protos.agent.v1.agent_pb2'
  # @@protoc_insertion_point(class_scope:v1.agent.CreateEventResponse)
  })
_sym_db.RegisterMessage(CreateEventResponse)

CreateEventError = _reflection.GeneratedProtocolMessageType('CreateEventError', (_message.Message,), {
  'DESCRIPTOR' : _CREATEEVENTERROR,
  '__module__' : 'protos.agent.v1.agent_pb2'
  # @@protoc_insertion_point(class_scope:v1.agent.CreateEventError)
  })
_sym_db.RegisterMessage(CreateEventError)

GetTeleopInfoRequest = _reflection.GeneratedProtocolMessageType('GetTeleopInfoRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETTELEOPINFOREQUEST,
  '__module__' : 'protos.agent.v1.agent_pb2'
  # @@protoc_insertion_point(class_scope:v1.agent.GetTeleopInfoRequest)
  })
_sym_db.RegisterMessage(GetTeleopInfoRequest)

GetTeleopInfoResponse = _reflection.GeneratedProtocolMessageType('GetTeleopInfoResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETTELEOPINFORESPONSE,
  '__module__' : 'protos.agent.v1.agent_pb2'
  # @@protoc_insertion_point(class_scope:v1.agent.GetTeleopInfoResponse)
  })
_sym_db.RegisterMessage(GetTeleopInfoResponse)

PostLanRtcOfferRequest = _reflection.GeneratedProtocolMessageType('PostLanRtcOfferRequest', (_message.Message,), {
  'DESCRIPTOR' : _POSTLANRTCOFFERREQUEST,
  '__module__' : 'protos.agent.v1.agent_pb2'
  # @@protoc_insertion_point(class_scope:v1.agent.PostLanRtcOfferRequest)
  })
_sym_db.RegisterMessage(PostLanRtcOfferRequest)

PostLanRtcOfferResponse = _reflection.GeneratedProtocolMessageType('PostLanRtcOfferResponse', (_message.Message,), {
  'DESCRIPTOR' : _POSTLANRTCOFFERRESPONSE,
  '__module__' : 'protos.agent.v1.agent_pb2'
  # @@protoc_insertion_point(class_scope:v1.agent.PostLanRtcOfferResponse)
  })
_sym_db.RegisterMessage(PostLanRtcOfferResponse)

SendOnCustomDataChannelRequest = _reflection.GeneratedProtocolMessageType('SendOnCustomDataChannelRequest', (_message.Message,), {
  'DESCRIPTOR' : _SENDONCUSTOMDATACHANNELREQUEST,
  '__module__' : 'protos.agent.v1.agent_pb2'
  # @@protoc_insertion_point(class_scope:v1.agent.SendOnCustomDataChannelRequest)
  })
_sym_db.RegisterMessage(SendOnCustomDataChannelRequest)

SendOnCustomDataChannelResponse = _reflection.GeneratedProtocolMessageType('SendOnCustomDataChannelResponse', (_message.Message,), {
  'DESCRIPTOR' : _SENDONCUSTOMDATACHANNELRESPONSE,
  '__module__' : 'protos.agent.v1.agent_pb2'
  # @@protoc_insertion_point(class_scope:v1.agent.SendOnCustomDataChannelResponse)
  })
_sym_db.RegisterMessage(SendOnCustomDataChannelResponse)

GetCustomDataChannelMessageStreamRequest = _reflection.GeneratedProtocolMessageType('GetCustomDataChannelMessageStreamRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETCUSTOMDATACHANNELMESSAGESTREAMREQUEST,
  '__module__' : 'protos.agent.v1.agent_pb2'
  # @@protoc_insertion_point(class_scope:v1.agent.GetCustomDataChannelMessageStreamRequest)
  })
_sym_db.RegisterMessage(GetCustomDataChannelMessageStreamRequest)

GetCustomDataChannelMessageStreamResponse = _reflection.GeneratedProtocolMessageType('GetCustomDataChannelMessageStreamResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETCUSTOMDATACHANNELMESSAGESTREAMRESPONSE,
  '__module__' : 'protos.agent.v1.agent_pb2'
  # @@protoc_insertion_point(class_scope:v1.agent.GetCustomDataChannelMessageStreamResponse)
  })
_sym_db.RegisterMessage(GetCustomDataChannelMessageStreamResponse)


DESCRIPTOR._options = None

_AGENT = _descriptor.ServiceDescriptor(
  name='Agent',
  full_name='v1.agent.Agent',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=3168,
  serialized_end=6146,
  methods=[
  _descriptor.MethodDescriptor(
    name='StreamData',
    full_name='v1.agent.Agent.StreamData',
    index=0,
    containing_service=None,
    input_type=protos_dot_model_dot_v1_dot_datapoint__pb2._DATAPOINT,
    output_type=_STREAMDATARESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='PostData',
    full_name='v1.agent.Agent.PostData',
    index=1,
    containing_service=None,
    input_type=protos_dot_model_dot_v1_dot_datapoint__pb2._DATAPOINT,
    output_type=_POSTDATARESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='PostDataMulti',
    full_name='v1.agent.Agent.PostDataMulti',
    index=2,
    containing_service=None,
    input_type=_POSTDATAMULTIREQUEST,
    output_type=_POSTDATAMULTIRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetTeleopControlDataStream',
    full_name='v1.agent.Agent.GetTeleopControlDataStream',
    index=3,
    containing_service=None,
    input_type=_GETTELEOPCONTROLDATASTREAMREQUEST,
    output_type=_GETTELEOPCONTROLDATASTREAMRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetTeleopHeartbeatStream',
    full_name='v1.agent.Agent.GetTeleopHeartbeatStream',
    index=4,
    containing_service=None,
    input_type=_GETTELEOPHEARTBEATSTREAMREQUEST,
    output_type=_GETTELEOPHEARTBEATSTREAMRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetTelemetryListenerStream',
    full_name='v1.agent.Agent.GetTelemetryListenerStream',
    index=5,
    containing_service=None,
    input_type=_GETTELEMETRYLISTENERSTREAMREQUEST,
    output_type=_GETTELEMETRYLISTENERSTREAMRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetCustomDataChannelMessageStream',
    full_name='v1.agent.Agent.GetCustomDataChannelMessageStream',
    index=6,
    containing_service=None,
    input_type=_GETCUSTOMDATACHANNELMESSAGESTREAMREQUEST,
    output_type=_GETCUSTOMDATACHANNELMESSAGESTREAMRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateEvent',
    full_name='v1.agent.Agent.CreateEvent',
    index=7,
    containing_service=None,
    input_type=_CREATEEVENTREQUEST,
    output_type=_CREATEEVENTRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateInterventionRequest',
    full_name='v1.agent.Agent.CreateInterventionRequest',
    index=8,
    containing_service=None,
    input_type=protos_dot_model_dot_v1_dot_intervention__pb2._INTERVENTIONREQUEST,
    output_type=protos_dot_model_dot_v1_dot_intervention__pb2._INTERVENTIONREQUEST,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetInterventionRequest',
    full_name='v1.agent.Agent.GetInterventionRequest',
    index=9,
    containing_service=None,
    input_type=_GETINTERVENTIONREQUESTREQUEST,
    output_type=protos_dot_model_dot_v1_dot_intervention__pb2._INTERVENTIONREQUEST,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetInterventionResponse',
    full_name='v1.agent.Agent.GetInterventionResponse',
    index=10,
    containing_service=None,
    input_type=_GETINTERVENTIONRESPONSEREQUEST,
    output_type=protos_dot_model_dot_v1_dot_intervention__pb2._INTERVENTIONRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetStreamsConfiguration',
    full_name='v1.agent.Agent.GetStreamsConfiguration',
    index=11,
    containing_service=None,
    input_type=_GETSTREAMSCONFIGURATIONREQUEST,
    output_type=_GETSTREAMSCONFIGURATIONRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetApplicationConfiguration',
    full_name='v1.agent.Agent.GetApplicationConfiguration',
    index=12,
    containing_service=None,
    input_type=_GETAPPLICATIONCONFIGURATIONREQUEST,
    output_type=_GETAPPLICATIONCONFIGURATIONRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetConfigBlobData',
    full_name='v1.agent.Agent.GetConfigBlobData',
    index=13,
    containing_service=None,
    input_type=_GETCONFIGBLOBDATAREQUEST,
    output_type=_GETCONFIGBLOBDATARESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetAgentConfiguration',
    full_name='v1.agent.Agent.GetAgentConfiguration',
    index=14,
    containing_service=None,
    input_type=_GETAGENTCONFIGURATIONREQUEST,
    output_type=_GETAGENTCONFIGURATIONRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetBufferMetadata',
    full_name='v1.agent.Agent.GetBufferMetadata',
    index=15,
    containing_service=None,
    input_type=_GETBUFFERMETADATAREQUEST,
    output_type=_GETBUFFERMETADATARESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='QueryDatapoints',
    full_name='v1.agent.Agent.QueryDatapoints',
    index=16,
    containing_service=None,
    input_type=_QUERYDATAPOINTSREQUEST,
    output_type=_QUERYDATAPOINTSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='QueryEvents',
    full_name='v1.agent.Agent.QueryEvents',
    index=17,
    containing_service=None,
    input_type=_QUERYEVENTSREQUEST,
    output_type=_QUERYEVENTSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Health',
    full_name='v1.agent.Agent.Health',
    index=18,
    containing_service=None,
    input_type=_HEALTHREQUEST,
    output_type=_HEALTHRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetCommandRequest',
    full_name='v1.agent.Agent.GetCommandRequest',
    index=19,
    containing_service=None,
    input_type=_GETCOMMANDREQUESTREQUEST,
    output_type=_GETCOMMANDREQUESTRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetCommandRequestStream',
    full_name='v1.agent.Agent.GetCommandRequestStream',
    index=20,
    containing_service=None,
    input_type=_GETCOMMANDREQUESTSTREAMREQUEST,
    output_type=_GETCOMMANDREQUESTSTREAMRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SendCommandResponse',
    full_name='v1.agent.Agent.SendCommandResponse',
    index=21,
    containing_service=None,
    input_type=_SENDCOMMANDRESPONSEREQUEST,
    output_type=_SENDCOMMANDRESPONSERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='PostTransformFrame',
    full_name='v1.agent.Agent.PostTransformFrame',
    index=22,
    containing_service=None,
    input_type=protos_dot_model_dot_v1_dot_math__pb2._TRANSFORMFRAME,
    output_type=_POSTTRANSFORMFRAMERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetBaseFrameID',
    full_name='v1.agent.Agent.SetBaseFrameID',
    index=23,
    containing_service=None,
    input_type=_SETBASEFRAMEIDREQUEST,
    output_type=_SETBASEFRAMEIDRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ClearTransformTree',
    full_name='v1.agent.Agent.ClearTransformTree',
    index=24,
    containing_service=None,
    input_type=_CLEARTRANSFORMTREEREQUEST,
    output_type=_CLEARTRANSFORMTREERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetTeleopInfo',
    full_name='v1.agent.Agent.GetTeleopInfo',
    index=25,
    containing_service=None,
    input_type=_GETTELEOPINFOREQUEST,
    output_type=_GETTELEOPINFORESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='PostLanRtcOffer',
    full_name='v1.agent.Agent.PostLanRtcOffer',
    index=26,
    containing_service=None,
    input_type=_POSTLANRTCOFFERREQUEST,
    output_type=_POSTLANRTCOFFERRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SendOnCustomDataChannel',
    full_name='v1.agent.Agent.SendOnCustomDataChannel',
    index=27,
    containing_service=None,
    input_type=_SENDONCUSTOMDATACHANNELREQUEST,
    output_type=_SENDONCUSTOMDATACHANNELRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='PostGenericAPIRequest',
    full_name='v1.agent.Agent.PostGenericAPIRequest',
    index=28,
    containing_service=None,
    input_type=protos_dot_model_dot_v1_dot_datapoint__pb2._GENERICAPIDATAPOINT,
    output_type=_POSTGENERICAPIREQUESTRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='PostGenericAPIUnbufferedRequest',
    full_name='v1.agent.Agent.PostGenericAPIUnbufferedRequest',
    index=29,
    containing_service=None,
    input_type=protos_dot_model_dot_v1_dot_datapoint__pb2._GENERICAPIDATAPOINT,
    output_type=_POSTGENERICAPIUNBUFFEREDREQUESTRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_AGENT)

DESCRIPTOR.services_by_name['Agent'] = _AGENT

# @@protoc_insertion_point(module_scope)




from formant.sdk.cloud.v2.formant_admin_api_client.models import DeviceOnlineEventSeverity, EventSeekQueryEventTypesItem, Comment, CustomEventMetadata, DatapointEventStreamType, EventSortOrder, CustomEventSeverity, DeviceOnlineEventMetadata, PortForwardingSessionRecordMetadata, StatefulEventMetadata, AnnotationTags, SystemEventTags, CommentType, SelectionRequestData, TeleopSessionRecordType, EventFilterEventTypesItem, CommandDeliveryEventStreamType, AnnotationMetadata, TeleopSessionRecord, EventCounts, EventFilter, CustomEventType, EventSeekQueryTypesItem, StatefulEventTags, TaskSummaryTags, EventQueryTypesItem, DeviceOfflineEventType, StatefulEvent, TaskSummary, DatapointEventTags, DeviceOnlineEventStreamType, PortForwardingSessionRecordStreamType, TeleopRequestData, CommandDeliveryEventType, EventListResponse, SystemEventStreamType, InterventionRequest, InterventionRequestStreamType, EventQuery, AnnotationType, PortForwardingSessionRecordType, EventFilterSeveritiesItem, EventTriggerCommand, TaskSummaryStreamType, DeviceOfflineEventStreamType, CustomEventStreamType, EventSeekQuerySeveritiesItem, AnnotationStreamType, DeviceOnlineEventTags, EventExportSheetRequest, LabeledPolygon, StatefulEventType, EventSeekQuery, InterventionRequestSeverity, CommentStreamType, DeviceOfflineEventSeverity, SystemEvent, Label, InterventionRequestTags, EventQueryEventTypesItem, InterventionRequestType, EventSeekQueryDirection, EventExportSheetResult, CustomEventTags, CommentTags, DeviceOnlineEventType, SystemEventType, LabelingRequestData, DeviceOnlineEvent, PortForwardingSessionRecordTags, CommandDeliveryEventTags, DeviceOfflineEvent, InterventionRequestMetadata, TaskSummaryMetadata, DeviceOfflineEventMetadata, EventSort, DatapointEventMetadata, PhysicalRequestData, TeleopSessionRecordTags, PortForwardingSessionRecord, CustomEvent, DeviceOfflineEventTags, DatapointEventType, InterventionRequestInterventionType, TeleopSessionRecordMetadata, SystemEventMetadata, StatefulEventSeverity, DatapointEventSeverity, EventHistogram, CommandDeliveryEventMetadata, EventQuerySeveritiesItem, EventHistogramEntry, EventFilterTypesItem, TeleopSessionRecordStreamType, Annotation, CommandDeliveryEvent, CommentMetadata, EventSortColumn, StatefulEventStreamType, DatapointEvent, TaskSummaryType, TaskSummaryReport
from formant.sdk.cloud.v2.formant_admin_api_client.api.event import event_controller_query
from formant.sdk.cloud.v2.formant_admin_api_client.types import *



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.device_teleop_custom_stream_configuration import DeviceTeleopCustomStreamConfiguration
    from ..models.device_teleop_hardware_stream_configuration import DeviceTeleopHardwareStreamConfiguration
    from ..models.device_teleop_ros_stream_configuration import DeviceTeleopRosStreamConfiguration
    from ..models.teleop_joystick_configuration import TeleopJoystickConfiguration
    from ..models.teleop_view_configuration import TeleopViewConfiguration


T = TypeVar("T", bound="DeviceTeleopConfiguration")


@attr.s(auto_attribs=True)
class DeviceTeleopConfiguration:
    """
    Attributes:
        ros_streams (Union[Unset, List['DeviceTeleopRosStreamConfiguration']]):
        custom_streams (Union[Unset, List['DeviceTeleopCustomStreamConfiguration']]):
        hardware_streams (Union[Unset, List['DeviceTeleopHardwareStreamConfiguration']]):
        joysticks (Union[Unset, TeleopJoystickConfiguration]):
        views (Union[Unset, TeleopViewConfiguration]):
        arm_switch (Union[Unset, bool]):
        allow_low_bandwidth_mode (Union[Unset, bool]):
        disable_high_ping_warning (Union[Unset, bool]):
    """

    ros_streams: Union[Unset, List["DeviceTeleopRosStreamConfiguration"]] = UNSET
    custom_streams: Union[Unset, List["DeviceTeleopCustomStreamConfiguration"]] = UNSET
    hardware_streams: Union[Unset, List["DeviceTeleopHardwareStreamConfiguration"]] = UNSET
    joysticks: Union[Unset, "TeleopJoystickConfiguration"] = UNSET
    views: Union[Unset, "TeleopViewConfiguration"] = UNSET
    arm_switch: Union[Unset, bool] = UNSET
    allow_low_bandwidth_mode: Union[Unset, bool] = UNSET
    disable_high_ping_warning: Union[Unset, bool] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        ros_streams: Union[Unset, List[Dict[str, Any]]] = UNSET
        if not isinstance(self.ros_streams, Unset):
            ros_streams = []
            for ros_streams_item_data in self.ros_streams:
                ros_streams_item = ros_streams_item_data.to_dict()

                ros_streams.append(ros_streams_item)

        custom_streams: Union[Unset, List[Dict[str, Any]]] = UNSET
        if not isinstance(self.custom_streams, Unset):
            custom_streams = []
            for custom_streams_item_data in self.custom_streams:
                custom_streams_item = custom_streams_item_data.to_dict()

                custom_streams.append(custom_streams_item)

        hardware_streams: Union[Unset, List[Dict[str, Any]]] = UNSET
        if not isinstance(self.hardware_streams, Unset):
            hardware_streams = []
            for hardware_streams_item_data in self.hardware_streams:
                hardware_streams_item = hardware_streams_item_data.to_dict()

                hardware_streams.append(hardware_streams_item)

        joysticks: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.joysticks, Unset):
            joysticks = self.joysticks.to_dict()

        views: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.views, Unset):
            views = self.views.to_dict()

        arm_switch = self.arm_switch
        allow_low_bandwidth_mode = self.allow_low_bandwidth_mode
        disable_high_ping_warning = self.disable_high_ping_warning

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if ros_streams is not UNSET:
            field_dict["rosStreams"] = ros_streams
        if custom_streams is not UNSET:
            field_dict["customStreams"] = custom_streams
        if hardware_streams is not UNSET:
            field_dict["hardwareStreams"] = hardware_streams
        if joysticks is not UNSET:
            field_dict["joysticks"] = joysticks
        if views is not UNSET:
            field_dict["views"] = views
        if arm_switch is not UNSET:
            field_dict["armSwitch"] = arm_switch
        if allow_low_bandwidth_mode is not UNSET:
            field_dict["allowLowBandwidthMode"] = allow_low_bandwidth_mode
        if disable_high_ping_warning is not UNSET:
            field_dict["disableHighPingWarning"] = disable_high_ping_warning

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.device_teleop_custom_stream_configuration import DeviceTeleopCustomStreamConfiguration
        from ..models.device_teleop_hardware_stream_configuration import DeviceTeleopHardwareStreamConfiguration
        from ..models.device_teleop_ros_stream_configuration import DeviceTeleopRosStreamConfiguration
        from ..models.teleop_joystick_configuration import TeleopJoystickConfiguration
        from ..models.teleop_view_configuration import TeleopViewConfiguration

        d = src_dict.copy()
        ros_streams = []
        _ros_streams = d.pop("rosStreams", UNSET)
        for ros_streams_item_data in _ros_streams or []:
            ros_streams_item = DeviceTeleopRosStreamConfiguration.from_dict(ros_streams_item_data)

            ros_streams.append(ros_streams_item)

        custom_streams = []
        _custom_streams = d.pop("customStreams", UNSET)
        for custom_streams_item_data in _custom_streams or []:
            custom_streams_item = DeviceTeleopCustomStreamConfiguration.from_dict(custom_streams_item_data)

            custom_streams.append(custom_streams_item)

        hardware_streams = []
        _hardware_streams = d.pop("hardwareStreams", UNSET)
        for hardware_streams_item_data in _hardware_streams or []:
            hardware_streams_item = DeviceTeleopHardwareStreamConfiguration.from_dict(hardware_streams_item_data)

            hardware_streams.append(hardware_streams_item)

        _joysticks = d.pop("joysticks", UNSET)
        joysticks: Union[Unset, TeleopJoystickConfiguration]
        if isinstance(_joysticks, Unset):
            joysticks = UNSET
        else:
            joysticks = TeleopJoystickConfiguration.from_dict(_joysticks)

        _views = d.pop("views", UNSET)
        views: Union[Unset, TeleopViewConfiguration]
        if isinstance(_views, Unset):
            views = UNSET
        else:
            views = TeleopViewConfiguration.from_dict(_views)

        arm_switch = d.pop("armSwitch", UNSET)

        allow_low_bandwidth_mode = d.pop("allowLowBandwidthMode", UNSET)

        disable_high_ping_warning = d.pop("disableHighPingWarning", UNSET)

        device_teleop_configuration = cls(
            ros_streams=ros_streams,
            custom_streams=custom_streams,
            hardware_streams=hardware_streams,
            joysticks=joysticks,
            views=views,
            arm_switch=arm_switch,
            allow_low_bandwidth_mode=allow_low_bandwidth_mode,
            disable_high_ping_warning=disable_high_ping_warning,
        )

        device_teleop_configuration.additional_properties = d
        return device_teleop_configuration

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



import datetime
from typing import Any, Dict, List, Optional, Type, TypeVar, Union

import attr
from dateutil.parser import isoparse

from ..models.adapter_cascading_configuration_specificity import AdapterCascadingConfigurationSpecificity
from ..models.adapter_cascading_configuration_type import AdapterCascadingConfigurationType
from ..types import UNSET, Unset

T = TypeVar("T", bound="AdapterCascadingConfiguration")


@attr.s(auto_attribs=True)
class AdapterCascadingConfiguration:
    """
    Attributes:
        type (AdapterCascadingConfigurationType):
        organization_id (str):
        entity_id (str):
        specificity (AdapterCascadingConfigurationSpecificity):
        specificity_id (str):
        id (Union[Unset, str]):
        created_at (Union[Unset, datetime.datetime]):
        updated_at (Union[Unset, datetime.datetime]):
        configuration (Optional[str]):
    """

    type: AdapterCascadingConfigurationType
    organization_id: str
    entity_id: str
    specificity: AdapterCascadingConfigurationSpecificity
    specificity_id: str
    configuration: Optional[str]
    id: Union[Unset, str] = UNSET
    created_at: Union[Unset, datetime.datetime] = UNSET
    updated_at: Union[Unset, datetime.datetime] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        type = self.type.value

        organization_id = self.organization_id
        entity_id = self.entity_id
        specificity = self.specificity.value

        specificity_id = self.specificity_id
        id = self.id
        created_at: Union[Unset, str] = UNSET
        if not isinstance(self.created_at, Unset):
            created_at = self.created_at.isoformat()

        updated_at: Union[Unset, str] = UNSET
        if not isinstance(self.updated_at, Unset):
            updated_at = self.updated_at.isoformat()

        configuration = self.configuration

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "type": type,
                "organizationId": organization_id,
                "entityId": entity_id,
                "specificity": specificity,
                "specificityId": specificity_id,
                "configuration": configuration,
            }
        )
        if id is not UNSET:
            field_dict["id"] = id
        if created_at is not UNSET:
            field_dict["createdAt"] = created_at
        if updated_at is not UNSET:
            field_dict["updatedAt"] = updated_at

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        type = AdapterCascadingConfigurationType(d.pop("type"))

        organization_id = d.pop("organizationId")

        entity_id = d.pop("entityId")

        specificity = AdapterCascadingConfigurationSpecificity(d.pop("specificity"))

        specificity_id = d.pop("specificityId")

        id = d.pop("id", UNSET)

        _created_at = d.pop("createdAt", UNSET)
        created_at: Union[Unset, datetime.datetime]
        if isinstance(_created_at, Unset):
            created_at = UNSET
        else:
            created_at = isoparse(_created_at)

        _updated_at = d.pop("updatedAt", UNSET)
        updated_at: Union[Unset, datetime.datetime]
        if isinstance(_updated_at, Unset):
            updated_at = UNSET
        else:
            updated_at = isoparse(_updated_at)

        configuration = d.pop("configuration")

        adapter_cascading_configuration = cls(
            type=type,
            organization_id=organization_id,
            entity_id=entity_id,
            specificity=specificity,
            specificity_id=specificity_id,
            id=id,
            created_at=created_at,
            updated_at=updated_at,
            configuration=configuration,
        )

        adapter_cascading_configuration.additional_properties = d
        return adapter_cascading_configuration

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..models.device_teleop_ros_stream_configuration_audio_codec import DeviceTeleopRosStreamConfigurationAudioCodec
from ..models.device_teleop_ros_stream_configuration_mode import DeviceTeleopRosStreamConfigurationMode
from ..models.device_teleop_ros_stream_configuration_numeric_control_visualization import (
    DeviceTeleopRosStreamConfigurationNumericControlVisualization,
)
from ..models.device_teleop_ros_stream_configuration_quality import DeviceTeleopRosStreamConfigurationQuality
from ..models.device_teleop_ros_stream_configuration_topic_type import DeviceTeleopRosStreamConfigurationTopicType
from ..types import UNSET, Unset

T = TypeVar("T", bound="DeviceTeleopRosStreamConfiguration")


@attr.s(auto_attribs=True)
class DeviceTeleopRosStreamConfiguration:
    """
    Attributes:
        topic_name (str):
        topic_type (DeviceTeleopRosStreamConfigurationTopicType):
        mode (DeviceTeleopRosStreamConfigurationMode):
        value_topic_name (Union[Unset, str]):
        encode_video (Union[Unset, bool]):
        overlay_clock (Union[Unset, bool]):
        status_topic (Union[Unset, str]):
        planned_topic (Union[Unset, str]):
        end_effector_topic (Union[Unset, str]):
        end_effector_link_name (Union[Unset, str]):
        plan_valid_topic (Union[Unset, str]):
        base_reference_frame (Union[Unset, str]):
        local_frame (Union[Unset, str]):
        audio_codec (Union[Unset, DeviceTeleopRosStreamConfigurationAudioCodec]):
        min_ (Union[Unset, float]):
        max_ (Union[Unset, float]):
        default_value (Union[Unset, float]):
        step (Union[Unset, float]):
        numeric_control_visualization (Union[Unset, DeviceTeleopRosStreamConfigurationNumericControlVisualization]):
        quality (Union[Unset, DeviceTeleopRosStreamConfigurationQuality]):
        mouse_events_target_stream (Union[Unset, str]):
        button_color (Union[Unset, str]):
        button_label (Union[Unset, str]):
        bitrate (Union[Unset, int]):
        disable_adaptive_quality (Union[Unset, bool]):
    """

    topic_name: str
    topic_type: DeviceTeleopRosStreamConfigurationTopicType
    mode: DeviceTeleopRosStreamConfigurationMode
    value_topic_name: Union[Unset, str] = UNSET
    encode_video: Union[Unset, bool] = UNSET
    overlay_clock: Union[Unset, bool] = UNSET
    status_topic: Union[Unset, str] = UNSET
    planned_topic: Union[Unset, str] = UNSET
    end_effector_topic: Union[Unset, str] = UNSET
    end_effector_link_name: Union[Unset, str] = UNSET
    plan_valid_topic: Union[Unset, str] = UNSET
    base_reference_frame: Union[Unset, str] = UNSET
    local_frame: Union[Unset, str] = UNSET
    audio_codec: Union[Unset, DeviceTeleopRosStreamConfigurationAudioCodec] = UNSET
    min_: Union[Unset, float] = UNSET
    max_: Union[Unset, float] = UNSET
    default_value: Union[Unset, float] = UNSET
    step: Union[Unset, float] = UNSET
    numeric_control_visualization: Union[Unset, DeviceTeleopRosStreamConfigurationNumericControlVisualization] = UNSET
    quality: Union[Unset, DeviceTeleopRosStreamConfigurationQuality] = UNSET
    mouse_events_target_stream: Union[Unset, str] = UNSET
    button_color: Union[Unset, str] = UNSET
    button_label: Union[Unset, str] = UNSET
    bitrate: Union[Unset, int] = UNSET
    disable_adaptive_quality: Union[Unset, bool] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        topic_name = self.topic_name
        topic_type = self.topic_type.value

        mode = self.mode.value

        value_topic_name = self.value_topic_name
        encode_video = self.encode_video
        overlay_clock = self.overlay_clock
        status_topic = self.status_topic
        planned_topic = self.planned_topic
        end_effector_topic = self.end_effector_topic
        end_effector_link_name = self.end_effector_link_name
        plan_valid_topic = self.plan_valid_topic
        base_reference_frame = self.base_reference_frame
        local_frame = self.local_frame
        audio_codec: Union[Unset, str] = UNSET
        if not isinstance(self.audio_codec, Unset):
            audio_codec = self.audio_codec.value

        min_ = self.min_
        max_ = self.max_
        default_value = self.default_value
        step = self.step
        numeric_control_visualization: Union[Unset, str] = UNSET
        if not isinstance(self.numeric_control_visualization, Unset):
            numeric_control_visualization = self.numeric_control_visualization.value

        quality: Union[Unset, str] = UNSET
        if not isinstance(self.quality, Unset):
            quality = self.quality.value

        mouse_events_target_stream = self.mouse_events_target_stream
        button_color = self.button_color
        button_label = self.button_label
        bitrate = self.bitrate
        disable_adaptive_quality = self.disable_adaptive_quality

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "topicName": topic_name,
                "topicType": topic_type,
                "mode": mode,
            }
        )
        if value_topic_name is not UNSET:
            field_dict["valueTopicName"] = value_topic_name
        if encode_video is not UNSET:
            field_dict["encodeVideo"] = encode_video
        if overlay_clock is not UNSET:
            field_dict["overlayClock"] = overlay_clock
        if status_topic is not UNSET:
            field_dict["statusTopic"] = status_topic
        if planned_topic is not UNSET:
            field_dict["plannedTopic"] = planned_topic
        if end_effector_topic is not UNSET:
            field_dict["endEffectorTopic"] = end_effector_topic
        if end_effector_link_name is not UNSET:
            field_dict["endEffectorLinkName"] = end_effector_link_name
        if plan_valid_topic is not UNSET:
            field_dict["planValidTopic"] = plan_valid_topic
        if base_reference_frame is not UNSET:
            field_dict["baseReferenceFrame"] = base_reference_frame
        if local_frame is not UNSET:
            field_dict["localFrame"] = local_frame
        if audio_codec is not UNSET:
            field_dict["audioCodec"] = audio_codec
        if min_ is not UNSET:
            field_dict["min"] = min_
        if max_ is not UNSET:
            field_dict["max"] = max_
        if default_value is not UNSET:
            field_dict["defaultValue"] = default_value
        if step is not UNSET:
            field_dict["step"] = step
        if numeric_control_visualization is not UNSET:
            field_dict["numericControlVisualization"] = numeric_control_visualization
        if quality is not UNSET:
            field_dict["quality"] = quality
        if mouse_events_target_stream is not UNSET:
            field_dict["mouseEventsTargetStream"] = mouse_events_target_stream
        if button_color is not UNSET:
            field_dict["buttonColor"] = button_color
        if button_label is not UNSET:
            field_dict["buttonLabel"] = button_label
        if bitrate is not UNSET:
            field_dict["bitrate"] = bitrate
        if disable_adaptive_quality is not UNSET:
            field_dict["disableAdaptiveQuality"] = disable_adaptive_quality

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        topic_name = d.pop("topicName")

        topic_type = DeviceTeleopRosStreamConfigurationTopicType(d.pop("topicType"))

        mode = DeviceTeleopRosStreamConfigurationMode(d.pop("mode"))

        value_topic_name = d.pop("valueTopicName", UNSET)

        encode_video = d.pop("encodeVideo", UNSET)

        overlay_clock = d.pop("overlayClock", UNSET)

        status_topic = d.pop("statusTopic", UNSET)

        planned_topic = d.pop("plannedTopic", UNSET)

        end_effector_topic = d.pop("endEffectorTopic", UNSET)

        end_effector_link_name = d.pop("endEffectorLinkName", UNSET)

        plan_valid_topic = d.pop("planValidTopic", UNSET)

        base_reference_frame = d.pop("baseReferenceFrame", UNSET)

        local_frame = d.pop("localFrame", UNSET)

        _audio_codec = d.pop("audioCodec", UNSET)
        audio_codec: Union[Unset, DeviceTeleopRosStreamConfigurationAudioCodec]
        if isinstance(_audio_codec, Unset):
            audio_codec = UNSET
        else:
            audio_codec = DeviceTeleopRosStreamConfigurationAudioCodec(_audio_codec)

        min_ = d.pop("min", UNSET)

        max_ = d.pop("max", UNSET)

        default_value = d.pop("defaultValue", UNSET)

        step = d.pop("step", UNSET)

        _numeric_control_visualization = d.pop("numericControlVisualization", UNSET)
        numeric_control_visualization: Union[Unset, DeviceTeleopRosStreamConfigurationNumericControlVisualization]
        if isinstance(_numeric_control_visualization, Unset):
            numeric_control_visualization = UNSET
        else:
            numeric_control_visualization = DeviceTeleopRosStreamConfigurationNumericControlVisualization(
                _numeric_control_visualization
            )

        _quality = d.pop("quality", UNSET)
        quality: Union[Unset, DeviceTeleopRosStreamConfigurationQuality]
        if isinstance(_quality, Unset):
            quality = UNSET
        else:
            quality = DeviceTeleopRosStreamConfigurationQuality(_quality)

        mouse_events_target_stream = d.pop("mouseEventsTargetStream", UNSET)

        button_color = d.pop("buttonColor", UNSET)

        button_label = d.pop("buttonLabel", UNSET)

        bitrate = d.pop("bitrate", UNSET)

        disable_adaptive_quality = d.pop("disableAdaptiveQuality", UNSET)

        device_teleop_ros_stream_configuration = cls(
            topic_name=topic_name,
            topic_type=topic_type,
            mode=mode,
            value_topic_name=value_topic_name,
            encode_video=encode_video,
            overlay_clock=overlay_clock,
            status_topic=status_topic,
            planned_topic=planned_topic,
            end_effector_topic=end_effector_topic,
            end_effector_link_name=end_effector_link_name,
            plan_valid_topic=plan_valid_topic,
            base_reference_frame=base_reference_frame,
            local_frame=local_frame,
            audio_codec=audio_codec,
            min_=min_,
            max_=max_,
            default_value=default_value,
            step=step,
            numeric_control_visualization=numeric_control_visualization,
            quality=quality,
            mouse_events_target_stream=mouse_events_target_stream,
            button_color=button_color,
            button_label=button_label,
            bitrate=bitrate,
            disable_adaptive_quality=disable_adaptive_quality,
        )

        device_teleop_ros_stream_configuration.additional_properties = d
        return device_teleop_ros_stream_configuration

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import Any, Dict, List, Type, TypeVar, Union, cast

import attr

from ..types import UNSET, Unset

T = TypeVar("T", bound="LookerInfo")


@attr.s(auto_attribs=True)
class LookerInfo:
    """
    Attributes:
        looker_group_id (int):
        looker_models (List[str]):
        looker_permissions (List[str]):
        looker_space_id (Union[Unset, float]):
    """

    looker_group_id: int
    looker_models: List[str]
    looker_permissions: List[str]
    looker_space_id: Union[Unset, float] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        looker_group_id = self.looker_group_id
        looker_models = self.looker_models

        looker_permissions = self.looker_permissions

        looker_space_id = self.looker_space_id

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "lookerGroupId": looker_group_id,
                "lookerModels": looker_models,
                "lookerPermissions": looker_permissions,
            }
        )
        if looker_space_id is not UNSET:
            field_dict["lookerSpaceId"] = looker_space_id

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        looker_group_id = d.pop("lookerGroupId")

        looker_models = cast(List[str], d.pop("lookerModels"))

        looker_permissions = cast(List[str], d.pop("lookerPermissions"))

        looker_space_id = d.pop("lookerSpaceId", UNSET)

        looker_info = cls(
            looker_group_id=looker_group_id,
            looker_models=looker_models,
            looker_permissions=looker_permissions,
            looker_space_id=looker_space_id,
        )

        looker_info.additional_properties = d
        return looker_info

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
